Introduction to OpenCV {#tutorial_table_of_content_introduction}
======================

Here you can read tutorials about how to set up your computer to work with the OpenCV library.
Additionally you can find very basic sample source code to introduce you to the world of the OpenCV.

-   @subpage tutorial_linux_install

    _Compatibility:_ \> OpenCV 2.0

    _Author:_ Ana Huamán

    We will learn how to setup OpenCV in your computer!

-   @subpage tutorial_linux_gcc_cmake

    _Compatibility:_ \> OpenCV 2.0

    _Author:_ Ana Huamán

    We will learn how to compile your first project using gcc and CMake

-   @subpage tutorial_linux_eclipse

    _Compatibility:_ \> OpenCV 2.0

    _Author:_ Ana Huamán

    We will learn how to compile your first project using the Eclipse environment

-   @subpage tutorial_windows_install

    _Compatibility:_ \> OpenCV 2.0

    _Author:_ Bernát Gábor

    You will learn how to setup OpenCV in your Windows Operating System!

-   @subpage tutorial_windows_visual_studio_opencv

    _Compatibility:_ \> OpenCV 2.0

    _Author:_ Bernát Gábor

    You will learn what steps you need to perform in order to use the OpenCV library inside a new
    Microsoft Visual Studio project.

-   @subpage tutorial_windows_visual_studio_image_watch

    _Compatibility:_ \>= OpenCV 2.4

    _Author:_ Wolf Kienzle

    You will learn how to visualize OpenCV matrices and images within Visual Studio 2012.

-   @subpage tutorial_java_dev_intro

    _Compatibility:_ \> OpenCV 2.4.4

    _Authors:_ Eric Christiansen and Andrey Pavlenko

    Explains how to build and run a simple desktop Java application using Eclipse, Ant or the
    Simple Build Tool (SBT).

-   @subpage tutorial_java_eclipse

    _Compatibility:_ \> OpenCV 2.4.4

    _Author:_ Barış Evrim Demiröz

    A tutorial on how to use OpenCV Java with Eclipse.

-   @subpage tutorial_clojure_dev_intro

    _Compatibility:_ \> OpenCV 2.4.4

    _Author:_ Mimmo Cosenza

    A tutorial on how to interactively use OpenCV from the Clojure REPL.

-   @subpage tutorial_android_dev_intro

    _Compatibility:_ \> OpenCV 2.4.2

    _Author:_ Vsevolod Glumov

    Not a tutorial, but a guide introducing Android development basics and environment setup

-   @subpage tutorial_O4A_SDK

    _Compatibility:_ \> OpenCV 2.4.2

    _Author:_ Vsevolod Glumov

    OpenCV4Android SDK: general info, installation, running samples

-   @subpage tutorial_dev_with_OCV_on_Android

    _Compatibility:_ \> OpenCV 2.4.3

    _Author:_ Vsevolod Glumov

    Development with OpenCV4Android SDK

-   @subpage tutorial_android_ocl_intro

    _Compatibility:_ \>= OpenCV 3.0

    _Author:_ Andrey Pavlenko

    Modify Android camera preview with OpenCL

-   @subpage tutorial_ios_install

    _Compatibility:_ \> OpenCV 2.4.2

    _Author:_ Artem Myagkov, Eduard Feicho

    We will learn how to setup OpenCV for using it in iOS!

-   @subpage tutorial_arm_crosscompile_with_cmake

    _Compatibility:_ \> OpenCV 2.4.4

    _Author:_ Alexander Smorkalov

    We will learn how to setup OpenCV cross compilation environment for ARM Linux.

-   @subpage tutorial_building_tegra_cuda

    _Compatibility:_ \>= OpenCV 3.1.0

    _Author:_ Randy J. Ray

    This tutorial will help you build OpenCV 3.1.0 for NVIDIA<sup>&reg;</sup> Tegra<sup>&reg;</sup> systems with CUDA 8.0.

-   @subpage tutorial_display_image

    _Compatibility:_ \> OpenCV 2.0

    _Author:_ Ana Huamán

    We will learn how to display an image using OpenCV

-   @subpage tutorial_load_save_image

    _Compatibility:_ \> OpenCV 2.0

    _Author:_ Ana Huamán

    We will learn how to save an Image in OpenCV...plus a small conversion to grayscale

-   @subpage tutorial_biicode

    _Compatibility:_ \> OpenCV 2.4

    _Author:_ biicode

    We will learn how to setup and use OpenCV in Mac OS X, Linux and Windows

-   @subpage tutorial_documentation

    _Compatibility:_ \> OpenCV 3.0

    _Author:_ Maksim Shabunin

    This tutorial describes new documenting process and some useful Doxygen features.

-   @subpage tutorial_transition_guide

    _Author:_ Maksim Shabunin

    This document describes some aspects of 2.4 -> 3.0 transition process.

-   @subpage tutorial_cross_referencing

    _Compatibility:_ \> OpenCV 3.3.0

    _Author:_ Sebastian Höffner

    This document outlines how to create cross references to the OpenCV documentation from other Doxygen projects.
